/**********************************************************************
 * Class FilesystemExport
 *  
 * Copyright (c) 2005-2012, German National Library / Deutsche Nationalbibliothek
 * Adickesallee 1, D-60322 Frankfurt am Main, Federal Republic of Germany 
 *
 * This program is free software.
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * 
 * Kadir Karaca Kocer -- German National Library
 * 
 **********************************************************************/

package de.dnb.oai.harvester.handler.export.impl;

import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.OutputStream;
import java.text.SimpleDateFormat;
import java.util.Date;

import org.openarchives.oai.x20.RecordType;

import de.dnb.stm.handler.export.ExportHandler;
import de.dnb.stm.handler.export.ProcessorExportException;
import de.dnb.stm.processor.Processor;


/* *******************************************************************
 * CHANGELOG:
 * 2012-10-04 Use system temp dir instead of throwing exception.
 * Refactored 15.07.2008 by Kadir Karaca Kocer, German National Library
 * Created on 10.09.2005 by Alexander Slotta, German National Library
 **********************************************************************/

/**
 * @author slotta
 *
 */
public class FilesystemExport implements ExportHandler
{
    private final SimpleDateFormat FILENAME_DATEFORMAT = new SimpleDateFormat("yyyyMMddHHmmssSSS");
	private File dirname;	
	private String name;
	private long id;

	/**
	 * Constructor of class FilesystemExport.
	 * 
	 * @param directory the directory with path
	 * @author Kadir Karaca Kocer, German National Library
	 */
	public FilesystemExport(String directory) {
		if (directory == null) {
		    //throw new IllegalArgumentException("Directory name can not be null"); 
		    this.dirname = new File(System.getProperty("java.io.tmpdir"));
		    return;
		}
		
		this.dirname = new File(directory);
		if (!this.dirname.exists() || !this.dirname.isDirectory()) { 
			//throw new IllegalArgumentException("Directory name '" + directory + "' does not exist");
            this.dirname = new File(System.getProperty("java.io.tmpdir")); 
		}
	}

    /**
     * @see de.dnb.stm.handler.export.ExportHandler
     * @since 10.04.2006
     * @author Alexander Slotta
     */
    @Override
	public boolean save(Processor processor, Object record, String transactionId) throws ProcessorExportException, IOException {
        saveRecordIntoFile(processor, (RecordType)record);
        return true;
    }
    
    private void saveRecordIntoFile(Processor processor, RecordType record) throws ProcessorExportException, IOException {
        if (record.getMetadata() == null) 
            throw new ProcessorExportException("FileSystemExport.saveRecordIntoFile(): Metadata can not be NULL!");
        
        String currentDate = this.FILENAME_DATEFORMAT.format(new Date());
        String fileId = "oai_" + processor.getTask().getTaskId() + "_" + currentDate + "_" + (int) Math.round(Math.random() * 10000000) + ".xml";
        File f = new File(this.dirname, fileId);
        FileOutputStream out = new FileOutputStream(f);
        record.getMetadata().save(out);
        out.close();
    }

	/**
	 * Get the output stream.
	 * 
	 * @since 10.09.2005
	 * @author Alexander Slotta
	 * @param filename 
	 * @return The output stream
	 * @throws IOException 
	 */
	public OutputStream getOutputStream(String filename) throws IOException {
		File f = new File(this.dirname, filename);
		FileOutputStream out = new FileOutputStream(f);
		
		return out;
	}

	/**
	 * @return Returns the name.
	 * @author Kadir Karaca Kocer, German National Library
	 */
	@Override
	public String getName() {
		return this.name;
	}

	/**
	 * @param newName The name to set.
	 * @author Kadir Karaca Kocer, German National Library
	 */
	@Override
	public void setName(String newName) {
		this.name = newName;
	}

	/**
	 * @return Returns the id.
	 * @author Kadir Karaca Kocer, German National Library
	 */
	@Override
	public long getId() {
		return this.id;
	}

	/**
	 * @param newId The id to set.
	 * @author Kadir Karaca Kocer, German National Library
	 */
	@Override
	public void setId(long newId) {
		this.id = newId;
	}

}
