/**********************************************************************
 * Class HibernateRepositoryDao
 *  
 * Copyright (c) 2005-2012, German National Library / Deutsche Nationalbibliothek
 * Adickesallee 1, D-60322 Frankfurt am Main, Federal Republic of Germany 
 *
 * This program is free software.
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * 
 * Kadir Karaca Kocer -- German National Library
 * 
 **********************************************************************/

package de.dnb.oai.repository;

import java.util.List;
import org.springframework.orm.hibernate3.support.HibernateDaoSupport;

/**
 * Hibernate version of RepositoryDao
 * 
 * @author Kadir Karaca Kocer
 * @see RepositoryDao
 * @see org.springframework.orm.hibernate3.support.HibernateDaoSupport
 * @version 20090220
 */
public class HibernateRepositoryDao extends HibernateDaoSupport implements RepositoryDao
{

	/**
	 * {@inheritDoc}
	 */
	@Override
    public void deleteRepository(Repository rep) {
		getHibernateTemplate().delete(rep);
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
    @SuppressWarnings({ "cast", "unchecked" })
	public List<Repository> getRepositories() {
		List <Repository> rl = (List <Repository>) getHibernateTemplate().find("from Repository as repository");
		return rl;
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
    public Repository getRepositoryById(Long id) {
		return getHibernateTemplate().get(Repository.class, id);
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
    public void saveRepository(Repository rep) {
		getHibernateTemplate().saveOrUpdate(rep);		
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
    @SuppressWarnings({ "cast", "unchecked" })
	public List<Repository> getRepositoriesSortedByName() {
		List <Repository> rl = (List <Repository>) getHibernateTemplate().find("from Repository as repository order by repository.repositoryName");
		return rl;
	}

}
