/**********************************************************************
 * Interface RepositoryDao
 *  
 * Copyright (c) 2005-2012, German National Library / Deutsche Nationalbibliothek
 * Adickesallee 1, D-60322 Frankfurt am Main, Federal Republic of Germany 
 *
 * This program is free software.
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * 
 * Kadir Karaca Kocer -- German National Library
 * 
 **********************************************************************/

package de.dnb.oai.repository;

import java.util.List;

/** ********************************************************************
 * Interface defining a DAO for OAI-Repositories
 * 
 * @author Kadir Karaca Kocer, German National Library
 * @version 20090220
 * @see de.dnb.oai.repository.Repository      
 * @since 20081125
 **********************************************************************/

/* *******************************************************************
 * CHANGELOG:
 *   
 * Created on 25.11.2008 by Kadir Karaca Kocer, German National Library
 *******************************************************************
 */
public interface RepositoryDao
{
	/**
	 * Returns the list of registered OAI-Repositories.
	 * 
	 * @return The list of registered OAI-Repositories.
	 * @author Kadir Karaca Kocer, German National Library
	 */
    public List<Repository> getRepositories();
    
    /**
	 * Returns the list of registered OAI-Repositories.
	 * 
	 * @return The list of registered OAI-Repositories.
	 * @author Kadir Karaca Kocer, German National Library
	 */
    public List<Repository> getRepositoriesSortedByName();
	
    /**
     * Returns the OAI-Repository with the given unique id.
     * 
     * @param id Id of the repository.
     * @return The repository with the given id.
     * @author Kadir Karaca Kocer, German National Library
     */
	public Repository getRepositoryById(Long id);
	
	
    /**
     * Saves the given the OAI-Repository.
     * 
     * @param rep The repository to save.
     * @author Kadir Karaca Kocer, German National Library
     */
	public void saveRepository(Repository rep);
	
	
    /**
     * Deletes the given the OAI-Repository.
     * 
     * @param rep The repository to delete.
     * @author Kadir Karaca Kocer, German National Library
     */
	public void deleteRepository(Repository rep);
	
}
